package com.ynet.life.action;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEException;
import com.ynet.life.base.LifeDBAccess;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.loaf.LoafConstants;
import com.ynet.life.loaf.LoafTools;
import com.ynet.life.loaf.jdbc.LoafQueryFactory;
import com.ynet.life.loaf.jdbc.LoafQueryInterface;
import java.sql.Connection;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.LinkedList;
import java.util.List;
import java.util.StringTokenizer;
import java.util.regex.Matcher;

/* loaded from: com_ynet_life_action.jar:com/ynet/life/action/QueryDataPutIntoCtxUsingSpecialSQLAction.class */
public class QueryDataPutIntoCtxUsingSpecialSQLAction extends LifeJDBCAction {
    private static final String FIELD_SEPERATOR = "||";
    private static final String MULTI_RECORD = "1";
    private static final String ZERO_RECORD = "-1";
    private String querySql;
    private List inputFields;
    private List outputFields;

    public String execute(Context context) throws TranFailException {
        Connection connection = LifeDBAccess.getConnection(getDataSource());
        int paramFlag = 0;
        try {
            List input = new LinkedList();
            String finalSQL = LoafTools.preProcessSql(context, this.querySql, this.inputFields, input);
            LoafQueryInterface query = LoafQueryFactory.getNewQuery("", (String) null, finalSQL);
            try {
                ResultSet resultSet = query.getQueryStatement(connection, input).executeQuery();
                paramFlag = fillResultIntoContext(resultSet, context);
            } catch (SQLException ex) {
                throw new TranFailException("EBLN0000", ex);
            }
        } catch (GENEException e) {
            Trace.logError("LOAF", "查询异常", e);
        } finally {
            LifeDBAccess.releaseConnection(getDataSource(), connection);
        }
        if (paramFlag == 1) {
            return MULTI_RECORD;
        }
        if (paramFlag == -1) {
            return ZERO_RECORD;
        }
        return "0";
    }

    private int fillResultIntoContext(ResultSet rs, Context context) throws SQLException, GENEException {
        int dataSize = this.outputFields.size();
        if (rs.next()) {
            for (int i = 1; i <= dataSize; i++) {
                String dataFieldValue = rs.getString(i);
                context.setDataValue((String) this.outputFields.get(i - 1), dataFieldValue);
            }
            if (rs.next()) {
                return 1;
            }
            return 0;
        }
        return -1;
    }

    public void setOutputFields(String outputFields) {
        List result = new ArrayList();
        StringTokenizer toke = new StringTokenizer(outputFields, FIELD_SEPERATOR);
        while (toke.hasMoreElements()) {
            String input = ((String) toke.nextElement()).trim();
            result.add(input);
        }
        this.outputFields = result;
    }

    public void setQuerySql(String querySql) {
        this.querySql = LoafConstants.PATTERN_INPUT_FIELD.matcher(querySql).replaceAll("?");
        List result = new LinkedList();
        Matcher matcher = LoafConstants.PATTERN_INPUT_FIELD.matcher(querySql);
        while (matcher.find()) {
            String fieldName = matcher.group().substring(1);
            result.add(fieldName);
        }
        this.inputFields = result;
    }
}
